/* FSpotDatabaseBehavior.c generated by valac 0.32.1, the Vala compiler
 * generated from FSpotDatabaseBehavior.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <sqlite3.h>
#include <gee.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gobject/gvaluecollector.h>


#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY (data_imports_fspot_db_fspot_behavior_entry_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_BEHAVIOR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, DataImportsFSpotDbFSpotBehaviorEntry))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_BEHAVIOR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, DataImportsFSpotDbFSpotBehaviorEntryClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_BEHAVIOR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_BEHAVIOR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_BEHAVIOR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, DataImportsFSpotDbFSpotBehaviorEntryClass))

typedef struct _DataImportsFSpotDbFSpotBehaviorEntry DataImportsFSpotDbFSpotBehaviorEntry;
typedef struct _DataImportsFSpotDbFSpotBehaviorEntryClass DataImportsFSpotDbFSpotBehaviorEntryClass;
typedef struct _DataImportsFSpotDbFSpotBehaviorEntryPrivate DataImportsFSpotDbFSpotBehaviorEntryPrivate;

#define UTILS_TYPE_VERSION_NUMBER (utils_version_number_get_type ())
#define UTILS_VERSION_NUMBER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), UTILS_TYPE_VERSION_NUMBER, UtilsVersionNumber))
#define UTILS_VERSION_NUMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), UTILS_TYPE_VERSION_NUMBER, UtilsVersionNumberClass))
#define UTILS_IS_VERSION_NUMBER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), UTILS_TYPE_VERSION_NUMBER))
#define UTILS_IS_VERSION_NUMBER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), UTILS_TYPE_VERSION_NUMBER))
#define UTILS_VERSION_NUMBER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), UTILS_TYPE_VERSION_NUMBER, UtilsVersionNumberClass))

typedef struct _UtilsVersionNumber UtilsVersionNumber;
typedef struct _UtilsVersionNumberClass UtilsVersionNumberClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR (data_imports_fspot_db_fspot_table_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TABLE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TABLE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TABLE_BEHAVIOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehaviorIface))

typedef struct _DataImportsFSpotDbFSpotTableBehavior DataImportsFSpotDbFSpotTableBehavior;
typedef struct _DataImportsFSpotDbFSpotTableBehaviorIface DataImportsFSpotDbFSpotTableBehaviorIface;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _DataImportsFSpotDbParamSpecFSpotBehaviorEntry DataImportsFSpotDbParamSpecFSpotBehaviorEntry;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR (data_imports_fspot_db_fspot_database_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehaviorClass))

typedef struct _DataImportsFSpotDbFSpotDatabaseBehavior DataImportsFSpotDbFSpotDatabaseBehavior;
typedef struct _DataImportsFSpotDbFSpotDatabaseBehaviorClass DataImportsFSpotDbFSpotDatabaseBehaviorClass;
typedef struct _DataImportsFSpotDbFSpotDatabaseBehaviorPrivate DataImportsFSpotDbFSpotDatabaseBehaviorPrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW (data_imports_fspot_db_fspot_photo_row_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, DataImportsFSpotDbFSpotPhotoRow))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, DataImportsFSpotDbFSpotPhotoRowClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_ROW, DataImportsFSpotDbFSpotPhotoRowClass))

typedef struct _DataImportsFSpotDbFSpotPhotoRow DataImportsFSpotDbFSpotPhotoRow;
typedef struct _DataImportsFSpotDbFSpotPhotoRowClass DataImportsFSpotDbFSpotPhotoRowClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAG_ROW (data_imports_fspot_db_fspot_tag_row_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TAG_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAG_ROW, DataImportsFSpotDbFSpotTagRow))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TAG_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAG_ROW, DataImportsFSpotDbFSpotTagRowClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TAG_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAG_ROW))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TAG_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAG_ROW))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TAG_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAG_ROW, DataImportsFSpotDbFSpotTagRowClass))

typedef struct _DataImportsFSpotDbFSpotTagRow DataImportsFSpotDbFSpotTagRow;
typedef struct _DataImportsFSpotDbFSpotTagRowClass DataImportsFSpotDbFSpotTagRowClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAG_ROW (data_imports_fspot_db_fspot_photo_tag_row_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAG_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAG_ROW, DataImportsFSpotDbFSpotPhotoTagRow))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAG_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAG_ROW, DataImportsFSpotDbFSpotPhotoTagRowClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_TAG_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAG_ROW))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_TAG_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAG_ROW))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAG_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAG_ROW, DataImportsFSpotDbFSpotPhotoTagRowClass))

typedef struct _DataImportsFSpotDbFSpotPhotoTagRow DataImportsFSpotDbFSpotPhotoTagRow;
typedef struct _DataImportsFSpotDbFSpotPhotoTagRowClass DataImportsFSpotDbFSpotPhotoTagRowClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW (data_imports_fspot_db_fspot_photo_version_row_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSION_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, DataImportsFSpotDbFSpotPhotoVersionRow))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSION_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, DataImportsFSpotDbFSpotPhotoVersionRowClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSION_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSION_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSION_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSION_ROW, DataImportsFSpotDbFSpotPhotoVersionRowClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionRow DataImportsFSpotDbFSpotPhotoVersionRow;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionRowClass DataImportsFSpotDbFSpotPhotoVersionRowClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLL_ROW (data_imports_fspot_db_fspot_roll_row_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLL_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLL_ROW, DataImportsFSpotDbFSpotRollRow))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLL_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLL_ROW, DataImportsFSpotDbFSpotRollRowClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_ROLL_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLL_ROW))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_ROLL_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLL_ROW))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLL_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLL_ROW, DataImportsFSpotDbFSpotRollRowClass))

typedef struct _DataImportsFSpotDbFSpotRollRow DataImportsFSpotDbFSpotRollRow;
typedef struct _DataImportsFSpotDbFSpotRollRowClass DataImportsFSpotDbFSpotRollRowClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR (data_imports_fspot_db_fspot_photos_v0_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V0_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV0BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV0Behavior DataImportsFSpotDbFSpotPhotosV0Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV0BehaviorClass DataImportsFSpotDbFSpotPhotosV0BehaviorClass;
#define _data_imports_fspot_db_fspot_behavior_entry_unref0(var) ((var == NULL) ? NULL : (var = (data_imports_fspot_db_fspot_behavior_entry_unref (var), NULL)))

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR (data_imports_fspot_db_fspot_photos_v5_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V5_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V5_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V5_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V5_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V5_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V5_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV5BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV5Behavior DataImportsFSpotDbFSpotPhotosV5Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV5BehaviorClass DataImportsFSpotDbFSpotPhotosV5BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR (data_imports_fspot_db_fspot_photos_v7_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V7_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V7_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V7_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V7_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V7_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V7_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV7BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV7Behavior DataImportsFSpotDbFSpotPhotosV7Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV7BehaviorClass DataImportsFSpotDbFSpotPhotosV7BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR (data_imports_fspot_db_fspot_photos_v11_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V11_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V11_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V11_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V11_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V11_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V11_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV11BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV11Behavior DataImportsFSpotDbFSpotPhotosV11Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV11BehaviorClass DataImportsFSpotDbFSpotPhotosV11BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR (data_imports_fspot_db_fspot_photos_v16_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V16_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V16_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V16_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V16_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V16_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV16BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV16Behavior DataImportsFSpotDbFSpotPhotosV16Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV16BehaviorClass DataImportsFSpotDbFSpotPhotosV16BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR (data_imports_fspot_db_fspot_photos_v17_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V17_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V17_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V17_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V17_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V17_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV17BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV17Behavior DataImportsFSpotDbFSpotPhotosV17Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV17BehaviorClass DataImportsFSpotDbFSpotPhotosV17BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR (data_imports_fspot_db_fspot_photos_v18_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V18_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V18_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V18_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTOS_V18_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_V18_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTOS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotosV18BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotosV18Behavior DataImportsFSpotDbFSpotPhotosV18Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotosV18BehaviorClass DataImportsFSpotDbFSpotPhotosV18BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAGS_V0_BEHAVIOR (data_imports_fspot_db_fspot_tags_v0_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TAGS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAGS_V0_BEHAVIOR, DataImportsFSpotDbFSpotTagsV0Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TAGS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAGS_V0_BEHAVIOR, DataImportsFSpotDbFSpotTagsV0BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TAGS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAGS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TAGS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAGS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TAGS_V0_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TAGS_V0_BEHAVIOR, DataImportsFSpotDbFSpotTagsV0BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotTagsV0Behavior DataImportsFSpotDbFSpotTagsV0Behavior;
typedef struct _DataImportsFSpotDbFSpotTagsV0BehaviorClass DataImportsFSpotDbFSpotTagsV0BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAGS_V0_BEHAVIOR (data_imports_fspot_db_fspot_photo_tags_v0_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAGS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAGS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoTagsV0Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAGS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAGS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoTagsV0BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_TAGS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAGS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_TAGS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAGS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAGS_V0_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_TAGS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoTagsV0BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoTagsV0Behavior DataImportsFSpotDbFSpotPhotoTagsV0Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoTagsV0BehaviorClass DataImportsFSpotDbFSpotPhotoTagsV0BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V0_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV0Behavior DataImportsFSpotDbFSpotPhotoVersionsV0Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV0BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V9_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV9Behavior DataImportsFSpotDbFSpotPhotoVersionsV9Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV9BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V16_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV16Behavior DataImportsFSpotDbFSpotPhotoVersionsV16Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV16BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V17_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV17Behavior DataImportsFSpotDbFSpotPhotoVersionsV17Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV17BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR (data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_PHOTO_VERSIONS_V18_BEHAVIOR, DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV18Behavior DataImportsFSpotDbFSpotPhotoVersionsV18Behavior;
typedef struct _DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass DataImportsFSpotDbFSpotPhotoVersionsV18BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V0_BEHAVIOR (data_imports_fspot_db_fspot_rolls_v0_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V0_BEHAVIOR, DataImportsFSpotDbFSpotRollsV0Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V0_BEHAVIOR, DataImportsFSpotDbFSpotRollsV0BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_ROLLS_V0_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_ROLLS_V0_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V0_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_V0_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V0_BEHAVIOR, DataImportsFSpotDbFSpotRollsV0BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotRollsV0Behavior DataImportsFSpotDbFSpotRollsV0Behavior;
typedef struct _DataImportsFSpotDbFSpotRollsV0BehaviorClass DataImportsFSpotDbFSpotRollsV0BehaviorClass;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V5_BEHAVIOR (data_imports_fspot_db_fspot_rolls_v5_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_V5_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V5_BEHAVIOR, DataImportsFSpotDbFSpotRollsV5Behavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_V5_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V5_BEHAVIOR, DataImportsFSpotDbFSpotRollsV5BehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_ROLLS_V5_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V5_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_ROLLS_V5_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V5_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_V5_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_ROLLS_V5_BEHAVIOR, DataImportsFSpotDbFSpotRollsV5BehaviorClass))

typedef struct _DataImportsFSpotDbFSpotRollsV5Behavior DataImportsFSpotDbFSpotRollsV5Behavior;
typedef struct _DataImportsFSpotDbFSpotRollsV5BehaviorClass DataImportsFSpotDbFSpotRollsV5BehaviorClass;
#define _g_free0(var) (var = (g_free (var), NULL))

struct _DataImportsFSpotDbFSpotBehaviorEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DataImportsFSpotDbFSpotBehaviorEntryPrivate * priv;
};

struct _DataImportsFSpotDbFSpotBehaviorEntryClass {
	GTypeClass parent_class;
	void (*finalize) (DataImportsFSpotDbFSpotBehaviorEntry *self);
};

struct _DataImportsFSpotDbFSpotTableBehaviorIface {
	GTypeInterface parent_iface;
	gchar* (*get_table_name) (DataImportsFSpotDbFSpotTableBehavior* self);
	gchar** (*list_columns) (DataImportsFSpotDbFSpotTableBehavior* self, int* result_length1);
	void (*build_row) (DataImportsFSpotDbFSpotTableBehavior* self, sqlite3_stmt* stmt, gpointer* row, gint offset);
};

struct _DataImportsFSpotDbFSpotBehaviorEntryPrivate {
	UtilsVersionNumber* version;
	DataImportsFSpotDbFSpotTableBehavior* behavior;
};

struct _DataImportsFSpotDbParamSpecFSpotBehaviorEntry {
	GParamSpec parent_instance;
};

struct _DataImportsFSpotDbFSpotDatabaseBehavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotDatabaseBehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotDatabaseBehaviorClass {
	GObjectClass parent_class;
};

struct _DataImportsFSpotDbFSpotDatabaseBehaviorPrivate {
	DataImportsFSpotDbFSpotTableBehavior* photos_behavior;
	DataImportsFSpotDbFSpotTableBehavior* tags_behavior;
	DataImportsFSpotDbFSpotTableBehavior* photo_tags_behavior;
	DataImportsFSpotDbFSpotTableBehavior* photo_versions_behavior;
	DataImportsFSpotDbFSpotTableBehavior* rolls_behavior;
};


static gpointer data_imports_fspot_db_fspot_behavior_entry_parent_class = NULL;
static gpointer data_imports_fspot_db_fspot_database_behavior_parent_class = NULL;
extern UtilsVersionNumber* data_imports_fspot_db_fspot_database_behavior_MIN_UNSUPPORTED_VERSION;
UtilsVersionNumber* data_imports_fspot_db_fspot_database_behavior_MIN_UNSUPPORTED_VERSION = NULL;
static GeeMap* data_imports_fspot_db_fspot_database_behavior_behavior_map;
static GeeMap* data_imports_fspot_db_fspot_database_behavior_behavior_map = NULL;

gpointer data_imports_fspot_db_fspot_behavior_entry_ref (gpointer instance);
void data_imports_fspot_db_fspot_behavior_entry_unref (gpointer instance);
GParamSpec* data_imports_fspot_db_param_spec_fspot_behavior_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void data_imports_fspot_db_value_set_fspot_behavior_entry (GValue* value, gpointer v_object);
void data_imports_fspot_db_value_take_fspot_behavior_entry (GValue* value, gpointer v_object);
gpointer data_imports_fspot_db_value_get_fspot_behavior_entry (const GValue* value);
GType data_imports_fspot_db_fspot_behavior_entry_get_type (void) G_GNUC_CONST;
GType utils_version_number_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_table_behavior_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_FSPOT_DB_FSPOT_BEHAVIOR_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, DataImportsFSpotDbFSpotBehaviorEntryPrivate))
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_BEHAVIOR_ENTRY_DUMMY_PROPERTY
};
DataImportsFSpotDbFSpotBehaviorEntry* data_imports_fspot_db_fspot_behavior_entry_new (UtilsVersionNumber* version, DataImportsFSpotDbFSpotTableBehavior* behavior);
DataImportsFSpotDbFSpotBehaviorEntry* data_imports_fspot_db_fspot_behavior_entry_construct (GType object_type, UtilsVersionNumber* version, DataImportsFSpotDbFSpotTableBehavior* behavior);
UtilsVersionNumber* data_imports_fspot_db_fspot_behavior_entry_get_version (DataImportsFSpotDbFSpotBehaviorEntry* self);
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_behavior_entry_get_behavior (DataImportsFSpotDbFSpotBehaviorEntry* self);
static void data_imports_fspot_db_fspot_behavior_entry_finalize (DataImportsFSpotDbFSpotBehaviorEntry* obj);
GType data_imports_fspot_db_fspot_database_behavior_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_photo_row_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_tag_row_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_photo_tag_row_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_photo_version_row_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_roll_row_get_type (void) G_GNUC_CONST;
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehaviorPrivate))
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_DUMMY_PROPERTY
};
UtilsVersionNumber* utils_version_number_new (gint* version, int version_length1);
UtilsVersionNumber* utils_version_number_construct (GType object_type, gint* version, int version_length1);
void data_imports_fspot_db_fspot_database_behavior_create_behavior_map (void);
GType data_imports_fspot_db_fspot_photos_v0_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotosV0Behavior* data_imports_fspot_db_fspot_photos_v0_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photos_v5_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotosV5Behavior* data_imports_fspot_db_fspot_photos_v5_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photos_v7_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotosV7Behavior* data_imports_fspot_db_fspot_photos_v7_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photos_v11_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotosV11Behavior* data_imports_fspot_db_fspot_photos_v11_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photos_v16_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotosV16Behavior* data_imports_fspot_db_fspot_photos_v16_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photos_v17_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotosV17Behavior* data_imports_fspot_db_fspot_photos_v17_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photos_v18_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotosV18Behavior* data_imports_fspot_db_fspot_photos_v18_behavior_get_instance (void);
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME "Photos"
GType data_imports_fspot_db_fspot_tags_v0_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotTagsV0Behavior* data_imports_fspot_db_fspot_tags_v0_behavior_get_instance (void);
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TAGS_TABLE_TABLE_NAME "Tags"
GType data_imports_fspot_db_fspot_photo_tags_v0_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotoTagsV0Behavior* data_imports_fspot_db_fspot_photo_tags_v0_behavior_get_instance (void);
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAGS_TABLE_TABLE_NAME "Photo_Tags"
GType data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_instance (void);
#define DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME "Photo_versions"
GType data_imports_fspot_db_fspot_rolls_v0_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotRollsV0Behavior* data_imports_fspot_db_fspot_rolls_v0_behavior_get_instance (void);
GType data_imports_fspot_db_fspot_rolls_v5_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotRollsV5Behavior* data_imports_fspot_db_fspot_rolls_v5_behavior_get_instance (void);
#define DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_TABLE_TABLE_NAME "Rolls"
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_find_behavior (const gchar* table_name, UtilsVersionNumber* version);
DataImportsFSpotDbFSpotDatabaseBehavior* data_imports_fspot_db_fspot_database_behavior_new (UtilsVersionNumber* version, GError** error);
DataImportsFSpotDbFSpotDatabaseBehavior* data_imports_fspot_db_fspot_database_behavior_construct (GType object_type, UtilsVersionNumber* version, GError** error);
gchar* utils_version_number_to_string (UtilsVersionNumber* self);
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_photos_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self);
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_tags_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self);
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_photo_tags_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self);
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_photo_versions_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self);
DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_rolls_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self);
static void data_imports_fspot_db_fspot_database_behavior_finalize (GObject* obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return self ? g_object_ref (self) : NULL;
#line 410 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotBehaviorEntry* data_imports_fspot_db_fspot_behavior_entry_construct (GType object_type, UtilsVersionNumber* version, DataImportsFSpotDbFSpotTableBehavior* behavior) {
	DataImportsFSpotDbFSpotBehaviorEntry* self = NULL;
	UtilsVersionNumber* _tmp0_ = NULL;
	UtilsVersionNumber* _tmp1_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp2_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp3_ = NULL;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (UTILS_IS_VERSION_NUMBER (version), NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TABLE_BEHAVIOR (behavior), NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self = (DataImportsFSpotDbFSpotBehaviorEntry*) g_type_create_instance (object_type);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = version;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->version);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self->priv->version = _tmp1_;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp2_ = behavior;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->behavior);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self->priv->behavior = _tmp3_;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return self;
#line 444 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotBehaviorEntry* data_imports_fspot_db_fspot_behavior_entry_new (UtilsVersionNumber* version, DataImportsFSpotDbFSpotTableBehavior* behavior) {
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return data_imports_fspot_db_fspot_behavior_entry_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, version, behavior);
#line 451 "FSpotDatabaseBehavior.c"
}


UtilsVersionNumber* data_imports_fspot_db_fspot_behavior_entry_get_version (DataImportsFSpotDbFSpotBehaviorEntry* self) {
	UtilsVersionNumber* result = NULL;
	UtilsVersionNumber* _tmp0_ = NULL;
	UtilsVersionNumber* _tmp1_ = NULL;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_BEHAVIOR_ENTRY (self), NULL);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = self->priv->version;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	result = _tmp1_;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return result;
#line 469 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_behavior_entry_get_behavior (DataImportsFSpotDbFSpotBehaviorEntry* self) {
	DataImportsFSpotDbFSpotTableBehavior* result = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp0_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp1_ = NULL;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_BEHAVIOR_ENTRY (self), NULL);
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = self->priv->behavior;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	result = _tmp1_;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return result;
#line 487 "FSpotDatabaseBehavior.c"
}


static void data_imports_fspot_db_value_fspot_behavior_entry_init (GValue* value) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	value->data[0].v_pointer = NULL;
#line 494 "FSpotDatabaseBehavior.c"
}


static void data_imports_fspot_db_value_fspot_behavior_entry_free_value (GValue* value) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		data_imports_fspot_db_fspot_behavior_entry_unref (value->data[0].v_pointer);
#line 503 "FSpotDatabaseBehavior.c"
	}
}


static void data_imports_fspot_db_value_fspot_behavior_entry_copy_value (const GValue* src_value, GValue* dest_value) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (src_value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		dest_value->data[0].v_pointer = data_imports_fspot_db_fspot_behavior_entry_ref (src_value->data[0].v_pointer);
#line 513 "FSpotDatabaseBehavior.c"
	} else {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		dest_value->data[0].v_pointer = NULL;
#line 517 "FSpotDatabaseBehavior.c"
	}
}


static gpointer data_imports_fspot_db_value_fspot_behavior_entry_peek_pointer (const GValue* value) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return value->data[0].v_pointer;
#line 525 "FSpotDatabaseBehavior.c"
}


static gchar* data_imports_fspot_db_value_fspot_behavior_entry_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (collect_values[0].v_pointer) {
#line 532 "FSpotDatabaseBehavior.c"
		DataImportsFSpotDbFSpotBehaviorEntry* object;
		object = collect_values[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		if (object->parent_instance.g_class == NULL) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 539 "FSpotDatabaseBehavior.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 543 "FSpotDatabaseBehavior.c"
		}
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		value->data[0].v_pointer = data_imports_fspot_db_fspot_behavior_entry_ref (object);
#line 547 "FSpotDatabaseBehavior.c"
	} else {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		value->data[0].v_pointer = NULL;
#line 551 "FSpotDatabaseBehavior.c"
	}
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return NULL;
#line 555 "FSpotDatabaseBehavior.c"
}


static gchar* data_imports_fspot_db_value_fspot_behavior_entry_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	DataImportsFSpotDbFSpotBehaviorEntry** object_p;
	object_p = collect_values[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (!object_p) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 566 "FSpotDatabaseBehavior.c"
	}
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (!value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		*object_p = NULL;
#line 572 "FSpotDatabaseBehavior.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		*object_p = value->data[0].v_pointer;
#line 576 "FSpotDatabaseBehavior.c"
	} else {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		*object_p = data_imports_fspot_db_fspot_behavior_entry_ref (value->data[0].v_pointer);
#line 580 "FSpotDatabaseBehavior.c"
	}
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return NULL;
#line 584 "FSpotDatabaseBehavior.c"
}


GParamSpec* data_imports_fspot_db_param_spec_fspot_behavior_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	DataImportsFSpotDbParamSpecFSpotBehaviorEntry* spec;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (g_type_is_a (object_type, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY), NULL);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return G_PARAM_SPEC (spec);
#line 598 "FSpotDatabaseBehavior.c"
}


gpointer data_imports_fspot_db_value_get_fspot_behavior_entry (const GValue* value) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY), NULL);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return value->data[0].v_pointer;
#line 607 "FSpotDatabaseBehavior.c"
}


void data_imports_fspot_db_value_set_fspot_behavior_entry (GValue* value, gpointer v_object) {
	DataImportsFSpotDbFSpotBehaviorEntry* old;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY));
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	old = value->data[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (v_object) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY));
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		value->data[0].v_pointer = v_object;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		data_imports_fspot_db_fspot_behavior_entry_ref (value->data[0].v_pointer);
#line 627 "FSpotDatabaseBehavior.c"
	} else {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		value->data[0].v_pointer = NULL;
#line 631 "FSpotDatabaseBehavior.c"
	}
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (old) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		data_imports_fspot_db_fspot_behavior_entry_unref (old);
#line 637 "FSpotDatabaseBehavior.c"
	}
}


void data_imports_fspot_db_value_take_fspot_behavior_entry (GValue* value, gpointer v_object) {
	DataImportsFSpotDbFSpotBehaviorEntry* old;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY));
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	old = value->data[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (v_object) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY));
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		value->data[0].v_pointer = v_object;
#line 656 "FSpotDatabaseBehavior.c"
	} else {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		value->data[0].v_pointer = NULL;
#line 660 "FSpotDatabaseBehavior.c"
	}
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (old) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		data_imports_fspot_db_fspot_behavior_entry_unref (old);
#line 666 "FSpotDatabaseBehavior.c"
	}
}


static void data_imports_fspot_db_fspot_behavior_entry_class_init (DataImportsFSpotDbFSpotBehaviorEntryClass * klass) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	data_imports_fspot_db_fspot_behavior_entry_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	((DataImportsFSpotDbFSpotBehaviorEntryClass *) klass)->finalize = data_imports_fspot_db_fspot_behavior_entry_finalize;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_type_class_add_private (klass, sizeof (DataImportsFSpotDbFSpotBehaviorEntryPrivate));
#line 678 "FSpotDatabaseBehavior.c"
}


static void data_imports_fspot_db_fspot_behavior_entry_instance_init (DataImportsFSpotDbFSpotBehaviorEntry * self) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self->priv = DATA_IMPORTS_FSPOT_DB_FSPOT_BEHAVIOR_ENTRY_GET_PRIVATE (self);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self->ref_count = 1;
#line 687 "FSpotDatabaseBehavior.c"
}


static void data_imports_fspot_db_fspot_behavior_entry_finalize (DataImportsFSpotDbFSpotBehaviorEntry* obj) {
	DataImportsFSpotDbFSpotBehaviorEntry * self;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, DataImportsFSpotDbFSpotBehaviorEntry);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_signal_handlers_destroy (self);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->version);
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->behavior);
#line 701 "FSpotDatabaseBehavior.c"
}


GType data_imports_fspot_db_fspot_behavior_entry_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_behavior_entry_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_behavior_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { data_imports_fspot_db_value_fspot_behavior_entry_init, data_imports_fspot_db_value_fspot_behavior_entry_free_value, data_imports_fspot_db_value_fspot_behavior_entry_copy_value, data_imports_fspot_db_value_fspot_behavior_entry_peek_pointer, "p", data_imports_fspot_db_value_fspot_behavior_entry_collect_value, "p", data_imports_fspot_db_value_fspot_behavior_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotBehaviorEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_behavior_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotBehaviorEntry), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_behavior_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType data_imports_fspot_db_fspot_behavior_entry_type_id;
		data_imports_fspot_db_fspot_behavior_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "DataImportsFSpotDbFSpotBehaviorEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&data_imports_fspot_db_fspot_behavior_entry_type_id__volatile, data_imports_fspot_db_fspot_behavior_entry_type_id);
	}
	return data_imports_fspot_db_fspot_behavior_entry_type_id__volatile;
}


gpointer data_imports_fspot_db_fspot_behavior_entry_ref (gpointer instance) {
	DataImportsFSpotDbFSpotBehaviorEntry* self;
	self = instance;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_atomic_int_inc (&self->ref_count);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return instance;
#line 726 "FSpotDatabaseBehavior.c"
}


void data_imports_fspot_db_fspot_behavior_entry_unref (gpointer instance) {
	DataImportsFSpotDbFSpotBehaviorEntry* self;
	self = instance;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		DATA_IMPORTS_FSPOT_DB_FSPOT_BEHAVIOR_ENTRY_GET_CLASS (self)->finalize (self);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 739 "FSpotDatabaseBehavior.c"
	}
}


void data_imports_fspot_db_fspot_database_behavior_create_behavior_map (void) {
	GeeHashMap* _tmp0_ = NULL;
	GeeList* photos_list = NULL;
	GeeArrayList* _tmp1_ = NULL;
	gint* _tmp2_ = NULL;
	gint* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	UtilsVersionNumber* _tmp4_ = NULL;
	UtilsVersionNumber* _tmp5_ = NULL;
	DataImportsFSpotDbFSpotPhotosV0Behavior* _tmp6_ = NULL;
	DataImportsFSpotDbFSpotPhotosV0Behavior* _tmp7_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp8_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp9_ = NULL;
	gint* _tmp10_ = NULL;
	gint* _tmp11_ = NULL;
	gint _tmp11__length1 = 0;
	UtilsVersionNumber* _tmp12_ = NULL;
	UtilsVersionNumber* _tmp13_ = NULL;
	DataImportsFSpotDbFSpotPhotosV5Behavior* _tmp14_ = NULL;
	DataImportsFSpotDbFSpotPhotosV5Behavior* _tmp15_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp16_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp17_ = NULL;
	gint* _tmp18_ = NULL;
	gint* _tmp19_ = NULL;
	gint _tmp19__length1 = 0;
	UtilsVersionNumber* _tmp20_ = NULL;
	UtilsVersionNumber* _tmp21_ = NULL;
	DataImportsFSpotDbFSpotPhotosV7Behavior* _tmp22_ = NULL;
	DataImportsFSpotDbFSpotPhotosV7Behavior* _tmp23_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp24_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp25_ = NULL;
	gint* _tmp26_ = NULL;
	gint* _tmp27_ = NULL;
	gint _tmp27__length1 = 0;
	UtilsVersionNumber* _tmp28_ = NULL;
	UtilsVersionNumber* _tmp29_ = NULL;
	DataImportsFSpotDbFSpotPhotosV11Behavior* _tmp30_ = NULL;
	DataImportsFSpotDbFSpotPhotosV11Behavior* _tmp31_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp32_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp33_ = NULL;
	gint* _tmp34_ = NULL;
	gint* _tmp35_ = NULL;
	gint _tmp35__length1 = 0;
	UtilsVersionNumber* _tmp36_ = NULL;
	UtilsVersionNumber* _tmp37_ = NULL;
	DataImportsFSpotDbFSpotPhotosV16Behavior* _tmp38_ = NULL;
	DataImportsFSpotDbFSpotPhotosV16Behavior* _tmp39_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp40_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp41_ = NULL;
	gint* _tmp42_ = NULL;
	gint* _tmp43_ = NULL;
	gint _tmp43__length1 = 0;
	UtilsVersionNumber* _tmp44_ = NULL;
	UtilsVersionNumber* _tmp45_ = NULL;
	DataImportsFSpotDbFSpotPhotosV17Behavior* _tmp46_ = NULL;
	DataImportsFSpotDbFSpotPhotosV17Behavior* _tmp47_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp48_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp49_ = NULL;
	gint* _tmp50_ = NULL;
	gint* _tmp51_ = NULL;
	gint _tmp51__length1 = 0;
	UtilsVersionNumber* _tmp52_ = NULL;
	UtilsVersionNumber* _tmp53_ = NULL;
	DataImportsFSpotDbFSpotPhotosV18Behavior* _tmp54_ = NULL;
	DataImportsFSpotDbFSpotPhotosV18Behavior* _tmp55_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp56_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp57_ = NULL;
	GeeMap* _tmp58_ = NULL;
	GeeList* tags_list = NULL;
	GeeArrayList* _tmp59_ = NULL;
	gint* _tmp60_ = NULL;
	gint* _tmp61_ = NULL;
	gint _tmp61__length1 = 0;
	UtilsVersionNumber* _tmp62_ = NULL;
	UtilsVersionNumber* _tmp63_ = NULL;
	DataImportsFSpotDbFSpotTagsV0Behavior* _tmp64_ = NULL;
	DataImportsFSpotDbFSpotTagsV0Behavior* _tmp65_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp66_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp67_ = NULL;
	GeeMap* _tmp68_ = NULL;
	GeeList* photo_tags_list = NULL;
	GeeArrayList* _tmp69_ = NULL;
	gint* _tmp70_ = NULL;
	gint* _tmp71_ = NULL;
	gint _tmp71__length1 = 0;
	UtilsVersionNumber* _tmp72_ = NULL;
	UtilsVersionNumber* _tmp73_ = NULL;
	DataImportsFSpotDbFSpotPhotoTagsV0Behavior* _tmp74_ = NULL;
	DataImportsFSpotDbFSpotPhotoTagsV0Behavior* _tmp75_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp76_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp77_ = NULL;
	GeeMap* _tmp78_ = NULL;
	GeeList* photo_versions_list = NULL;
	GeeArrayList* _tmp79_ = NULL;
	gint* _tmp80_ = NULL;
	gint* _tmp81_ = NULL;
	gint _tmp81__length1 = 0;
	UtilsVersionNumber* _tmp82_ = NULL;
	UtilsVersionNumber* _tmp83_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* _tmp84_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV0Behavior* _tmp85_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp86_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp87_ = NULL;
	gint* _tmp88_ = NULL;
	gint* _tmp89_ = NULL;
	gint _tmp89__length1 = 0;
	UtilsVersionNumber* _tmp90_ = NULL;
	UtilsVersionNumber* _tmp91_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* _tmp92_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV9Behavior* _tmp93_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp94_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp95_ = NULL;
	gint* _tmp96_ = NULL;
	gint* _tmp97_ = NULL;
	gint _tmp97__length1 = 0;
	UtilsVersionNumber* _tmp98_ = NULL;
	UtilsVersionNumber* _tmp99_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* _tmp100_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV16Behavior* _tmp101_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp102_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp103_ = NULL;
	gint* _tmp104_ = NULL;
	gint* _tmp105_ = NULL;
	gint _tmp105__length1 = 0;
	UtilsVersionNumber* _tmp106_ = NULL;
	UtilsVersionNumber* _tmp107_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* _tmp108_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV17Behavior* _tmp109_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp110_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp111_ = NULL;
	gint* _tmp112_ = NULL;
	gint* _tmp113_ = NULL;
	gint _tmp113__length1 = 0;
	UtilsVersionNumber* _tmp114_ = NULL;
	UtilsVersionNumber* _tmp115_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* _tmp116_ = NULL;
	DataImportsFSpotDbFSpotPhotoVersionsV18Behavior* _tmp117_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp118_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp119_ = NULL;
	GeeMap* _tmp120_ = NULL;
	GeeList* rolls_list = NULL;
	GeeArrayList* _tmp121_ = NULL;
	gint* _tmp122_ = NULL;
	gint* _tmp123_ = NULL;
	gint _tmp123__length1 = 0;
	UtilsVersionNumber* _tmp124_ = NULL;
	UtilsVersionNumber* _tmp125_ = NULL;
	DataImportsFSpotDbFSpotRollsV0Behavior* _tmp126_ = NULL;
	DataImportsFSpotDbFSpotRollsV0Behavior* _tmp127_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp128_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp129_ = NULL;
	gint* _tmp130_ = NULL;
	gint* _tmp131_ = NULL;
	gint _tmp131__length1 = 0;
	UtilsVersionNumber* _tmp132_ = NULL;
	UtilsVersionNumber* _tmp133_ = NULL;
	DataImportsFSpotDbFSpotRollsV5Behavior* _tmp134_ = NULL;
	DataImportsFSpotDbFSpotRollsV5Behavior* _tmp135_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp136_ = NULL;
	DataImportsFSpotDbFSpotBehaviorEntry* _tmp137_ = NULL;
	GeeMap* _tmp138_ = NULL;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, GEE_TYPE_LIST, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (data_imports_fspot_db_fspot_database_behavior_behavior_map);
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	data_imports_fspot_db_fspot_database_behavior_behavior_map = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_MAP, GeeMap);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = gee_array_list_new (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, (GBoxedCopyFunc) data_imports_fspot_db_fspot_behavior_entry_ref, data_imports_fspot_db_fspot_behavior_entry_unref, NULL, NULL, NULL);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	photos_list = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_LIST, GeeList);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp2_ = g_new0 (gint, 1);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp2_[0] = 0;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp3_ = _tmp2_;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp3__length1 = 1;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp4_ = utils_version_number_new (_tmp3_, 1);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp5_ = _tmp4_;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp6_ = data_imports_fspot_db_fspot_photos_v0_behavior_get_instance ();
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp7_ = _tmp6_;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp8_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp5_, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp9_ = _tmp8_;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photos_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp9_);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp9_);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp7_);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp5_);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp3_ = (g_free (_tmp3_), NULL);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp10_ = g_new0 (gint, 1);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp10_[0] = 5;
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp11_ = _tmp10_;
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp11__length1 = 1;
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp12_ = utils_version_number_new (_tmp11_, 1);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp13_ = _tmp12_;
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp14_ = data_imports_fspot_db_fspot_photos_v5_behavior_get_instance ();
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp15_ = _tmp14_;
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp16_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp13_, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp17_ = _tmp16_;
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photos_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp17_);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp17_);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp15_);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp13_);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp11_ = (g_free (_tmp11_), NULL);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp18_ = g_new0 (gint, 1);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp18_[0] = 7;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp19_ = _tmp18_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp19__length1 = 1;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp20_ = utils_version_number_new (_tmp19_, 1);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp21_ = _tmp20_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp22_ = data_imports_fspot_db_fspot_photos_v7_behavior_get_instance ();
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp23_ = _tmp22_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp24_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp21_, G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp25_ = _tmp24_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photos_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp25_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp25_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp23_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp21_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp19_ = (g_free (_tmp19_), NULL);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp26_ = g_new0 (gint, 1);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp26_[0] = 11;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp27_ = _tmp26_;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp27__length1 = 1;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp28_ = utils_version_number_new (_tmp27_, 1);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp29_ = _tmp28_;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp30_ = data_imports_fspot_db_fspot_photos_v11_behavior_get_instance ();
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp31_ = _tmp30_;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp32_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp29_, G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp33_ = _tmp32_;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photos_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp33_);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp33_);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp31_);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp29_);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp27_ = (g_free (_tmp27_), NULL);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp34_ = g_new0 (gint, 1);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp34_[0] = 16;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp35_ = _tmp34_;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp35__length1 = 1;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp36_ = utils_version_number_new (_tmp35_, 1);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp37_ = _tmp36_;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp38_ = data_imports_fspot_db_fspot_photos_v16_behavior_get_instance ();
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp39_ = _tmp38_;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp40_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp37_, G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp41_ = _tmp40_;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photos_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp41_);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp41_);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp39_);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp37_);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp35_ = (g_free (_tmp35_), NULL);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp42_ = g_new0 (gint, 1);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp42_[0] = 17;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp43_ = _tmp42_;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp43__length1 = 1;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp44_ = utils_version_number_new (_tmp43_, 1);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp45_ = _tmp44_;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp46_ = data_imports_fspot_db_fspot_photos_v17_behavior_get_instance ();
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp47_ = _tmp46_;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp48_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp45_, G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp49_ = _tmp48_;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photos_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp49_);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp49_);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp47_);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp45_);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp43_ = (g_free (_tmp43_), NULL);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp50_ = g_new0 (gint, 1);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp50_[0] = 18;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp51_ = _tmp50_;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp51__length1 = 1;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp52_ = utils_version_number_new (_tmp51_, 1);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp53_ = _tmp52_;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp54_ = data_imports_fspot_db_fspot_photos_v18_behavior_get_instance ();
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp55_ = _tmp54_;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp56_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp53_, G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp57_ = _tmp56_;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photos_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp57_);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp57_);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp55_);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp53_);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp51_ = (g_free (_tmp51_), NULL);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp58_ = data_imports_fspot_db_fspot_database_behavior_behavior_map;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_map_set (_tmp58_, DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME, photos_list);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp59_ = gee_array_list_new (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, (GBoxedCopyFunc) data_imports_fspot_db_fspot_behavior_entry_ref, data_imports_fspot_db_fspot_behavior_entry_unref, NULL, NULL, NULL);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	tags_list = G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GEE_TYPE_LIST, GeeList);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp60_ = g_new0 (gint, 1);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp60_[0] = 0;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp61_ = _tmp60_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp61__length1 = 1;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp62_ = utils_version_number_new (_tmp61_, 1);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp63_ = _tmp62_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp64_ = data_imports_fspot_db_fspot_tags_v0_behavior_get_instance ();
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp65_ = _tmp64_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp66_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp63_, G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp67_ = _tmp66_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (tags_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp67_);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp67_);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp65_);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp63_);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp61_ = (g_free (_tmp61_), NULL);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp68_ = data_imports_fspot_db_fspot_database_behavior_behavior_map;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_map_set (_tmp68_, DATA_IMPORTS_FSPOT_DB_FSPOT_TAGS_TABLE_TABLE_NAME, tags_list);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp69_ = gee_array_list_new (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, (GBoxedCopyFunc) data_imports_fspot_db_fspot_behavior_entry_ref, data_imports_fspot_db_fspot_behavior_entry_unref, NULL, NULL, NULL);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	photo_tags_list = G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, GEE_TYPE_LIST, GeeList);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp70_ = g_new0 (gint, 1);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp70_[0] = 0;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp71_ = _tmp70_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp71__length1 = 1;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp72_ = utils_version_number_new (_tmp71_, 1);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp73_ = _tmp72_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp74_ = data_imports_fspot_db_fspot_photo_tags_v0_behavior_get_instance ();
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp75_ = _tmp74_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp76_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp73_, G_TYPE_CHECK_INSTANCE_CAST (_tmp75_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp77_ = _tmp76_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photo_tags_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp77_);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp77_);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp75_);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp73_);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp71_ = (g_free (_tmp71_), NULL);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp78_ = data_imports_fspot_db_fspot_database_behavior_behavior_map;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_map_set (_tmp78_, DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAGS_TABLE_TABLE_NAME, photo_tags_list);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp79_ = gee_array_list_new (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, (GBoxedCopyFunc) data_imports_fspot_db_fspot_behavior_entry_ref, data_imports_fspot_db_fspot_behavior_entry_unref, NULL, NULL, NULL);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	photo_versions_list = G_TYPE_CHECK_INSTANCE_CAST (_tmp79_, GEE_TYPE_LIST, GeeList);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp80_ = g_new0 (gint, 1);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp80_[0] = 0;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp81_ = _tmp80_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp81__length1 = 1;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp82_ = utils_version_number_new (_tmp81_, 1);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp83_ = _tmp82_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp84_ = data_imports_fspot_db_fspot_photo_versions_v0_behavior_get_instance ();
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp85_ = _tmp84_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp86_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp83_, G_TYPE_CHECK_INSTANCE_CAST (_tmp85_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp87_ = _tmp86_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photo_versions_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp87_);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp87_);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp85_);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp83_);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp81_ = (g_free (_tmp81_), NULL);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp88_ = g_new0 (gint, 1);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp88_[0] = 9;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp89_ = _tmp88_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp89__length1 = 1;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp90_ = utils_version_number_new (_tmp89_, 1);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp91_ = _tmp90_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp92_ = data_imports_fspot_db_fspot_photo_versions_v9_behavior_get_instance ();
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp93_ = _tmp92_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp94_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp91_, G_TYPE_CHECK_INSTANCE_CAST (_tmp93_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp95_ = _tmp94_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photo_versions_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp95_);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp95_);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp93_);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp91_);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp89_ = (g_free (_tmp89_), NULL);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp96_ = g_new0 (gint, 1);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp96_[0] = 16;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp97_ = _tmp96_;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp97__length1 = 1;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp98_ = utils_version_number_new (_tmp97_, 1);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp99_ = _tmp98_;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp100_ = data_imports_fspot_db_fspot_photo_versions_v16_behavior_get_instance ();
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp101_ = _tmp100_;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp102_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp99_, G_TYPE_CHECK_INSTANCE_CAST (_tmp101_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp103_ = _tmp102_;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photo_versions_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp103_);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp103_);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp101_);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp99_);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp97_ = (g_free (_tmp97_), NULL);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp104_ = g_new0 (gint, 1);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp104_[0] = 17;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp105_ = _tmp104_;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp105__length1 = 1;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp106_ = utils_version_number_new (_tmp105_, 1);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp107_ = _tmp106_;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp108_ = data_imports_fspot_db_fspot_photo_versions_v17_behavior_get_instance ();
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp109_ = _tmp108_;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp110_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp107_, G_TYPE_CHECK_INSTANCE_CAST (_tmp109_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp111_ = _tmp110_;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photo_versions_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp111_);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp111_);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp109_);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp107_);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp105_ = (g_free (_tmp105_), NULL);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp112_ = g_new0 (gint, 1);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp112_[0] = 18;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp113_ = _tmp112_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp113__length1 = 1;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp114_ = utils_version_number_new (_tmp113_, 1);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp115_ = _tmp114_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp116_ = data_imports_fspot_db_fspot_photo_versions_v18_behavior_get_instance ();
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp117_ = _tmp116_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp118_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp115_, G_TYPE_CHECK_INSTANCE_CAST (_tmp117_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp119_ = _tmp118_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (photo_versions_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp119_);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp119_);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp117_);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp115_);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp113_ = (g_free (_tmp113_), NULL);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp120_ = data_imports_fspot_db_fspot_database_behavior_behavior_map;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_map_set (_tmp120_, DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME, photo_versions_list);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp121_ = gee_array_list_new (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_BEHAVIOR_ENTRY, (GBoxedCopyFunc) data_imports_fspot_db_fspot_behavior_entry_ref, data_imports_fspot_db_fspot_behavior_entry_unref, NULL, NULL, NULL);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	rolls_list = G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, GEE_TYPE_LIST, GeeList);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp122_ = g_new0 (gint, 1);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp122_[0] = 0;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp123_ = _tmp122_;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp123__length1 = 1;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp124_ = utils_version_number_new (_tmp123_, 1);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp125_ = _tmp124_;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp126_ = data_imports_fspot_db_fspot_rolls_v0_behavior_get_instance ();
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp127_ = _tmp126_;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp128_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp125_, G_TYPE_CHECK_INSTANCE_CAST (_tmp127_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp129_ = _tmp128_;
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (rolls_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp129_);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp129_);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp127_);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp125_);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp123_ = (g_free (_tmp123_), NULL);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp130_ = g_new0 (gint, 1);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp130_[0] = 5;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp131_ = _tmp130_;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp131__length1 = 1;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp132_ = utils_version_number_new (_tmp131_, 1);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp133_ = _tmp132_;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp134_ = data_imports_fspot_db_fspot_rolls_v5_behavior_get_instance ();
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp135_ = _tmp134_;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp136_ = data_imports_fspot_db_fspot_behavior_entry_new (_tmp133_, G_TYPE_CHECK_INSTANCE_CAST (_tmp135_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp137_ = _tmp136_;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (rolls_list, GEE_TYPE_COLLECTION, GeeCollection), _tmp137_);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_data_imports_fspot_db_fspot_behavior_entry_unref0 (_tmp137_);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp135_);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (_tmp133_);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp131_ = (g_free (_tmp131_), NULL);
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp138_ = data_imports_fspot_db_fspot_database_behavior_behavior_map;
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	gee_map_set (_tmp138_, DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_TABLE_TABLE_NAME, rolls_list);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (rolls_list);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (photo_versions_list);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (photo_tags_list);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (tags_list);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (photos_list);
#line 1441 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_find_behavior (const gchar* table_name, UtilsVersionNumber* version) {
	DataImportsFSpotDbFSpotTableBehavior* result = NULL;
	DataImportsFSpotDbFSpotTableBehavior* behavior = NULL;
	GeeList* behavior_list = NULL;
	GeeMap* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gpointer _tmp2_ = NULL;
	GeeList* _tmp3_ = NULL;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (table_name != NULL, NULL);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (UTILS_IS_VERSION_NUMBER (version), NULL);
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	behavior = NULL;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = data_imports_fspot_db_fspot_database_behavior_behavior_map;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = table_name;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp2_ = gee_map_get (_tmp0_, _tmp1_);
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	behavior_list = (GeeList*) _tmp2_;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp3_ = behavior_list;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp3_ != NULL) {
#line 1471 "FSpotDatabaseBehavior.c"
		{
			GeeList* _entry_list = NULL;
			GeeList* _tmp4_ = NULL;
			GeeList* _tmp5_ = NULL;
			gint _entry_size = 0;
			GeeList* _tmp6_ = NULL;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			gint _entry_index = 0;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_tmp4_ = behavior_list;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_tmp5_ = _g_object_ref0 (_tmp4_);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_entry_list = _tmp5_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_tmp6_ = _entry_list;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_tmp7_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection));
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_tmp8_ = _tmp7_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_entry_size = _tmp8_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_entry_index = -1;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			while (TRUE) {
#line 1499 "FSpotDatabaseBehavior.c"
				gint _tmp9_ = 0;
				gint _tmp10_ = 0;
				gint _tmp11_ = 0;
				DataImportsFSpotDbFSpotBehaviorEntry* entry = NULL;
				GeeList* _tmp12_ = NULL;
				gint _tmp13_ = 0;
				gpointer _tmp14_ = NULL;
				UtilsVersionNumber* _tmp15_ = NULL;
				DataImportsFSpotDbFSpotBehaviorEntry* _tmp16_ = NULL;
				UtilsVersionNumber* _tmp17_ = NULL;
				UtilsVersionNumber* _tmp18_ = NULL;
				gint _tmp19_ = 0;
				gboolean _tmp20_ = FALSE;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp9_ = _entry_index;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_entry_index = _tmp9_ + 1;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp10_ = _entry_index;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp11_ = _entry_size;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				if (!(_tmp10_ < _tmp11_)) {
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
					break;
#line 1525 "FSpotDatabaseBehavior.c"
				}
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp12_ = _entry_list;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp13_ = _entry_index;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp14_ = gee_list_get (_tmp12_, _tmp13_);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				entry = (DataImportsFSpotDbFSpotBehaviorEntry*) _tmp14_;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp15_ = version;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp16_ = entry;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp17_ = data_imports_fspot_db_fspot_behavior_entry_get_version (_tmp16_);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp18_ = _tmp17_;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp19_ = gee_comparable_compare_to (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_COMPARABLE, GeeComparable), _tmp18_);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_tmp20_ = _tmp19_ >= 0;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_g_object_unref0 (_tmp18_);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				if (_tmp20_) {
#line 1551 "FSpotDatabaseBehavior.c"
					DataImportsFSpotDbFSpotBehaviorEntry* _tmp21_ = NULL;
					DataImportsFSpotDbFSpotTableBehavior* _tmp22_ = NULL;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
					_tmp21_ = entry;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
					_tmp22_ = data_imports_fspot_db_fspot_behavior_entry_get_behavior (_tmp21_);
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
					_g_object_unref0 (behavior);
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
					behavior = _tmp22_;
#line 1562 "FSpotDatabaseBehavior.c"
				}
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
				_data_imports_fspot_db_fspot_behavior_entry_unref0 (entry);
#line 1566 "FSpotDatabaseBehavior.c"
			}
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (_entry_list);
#line 1570 "FSpotDatabaseBehavior.c"
		}
	} else {
		const gchar* _tmp23_ = NULL;
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp23_ = table_name;
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		g_warning ("FSpotDatabaseBehavior.vala:155: Could not find behavior list for table" \
" %s", _tmp23_);
#line 1578 "FSpotDatabaseBehavior.c"
	}
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	result = behavior;
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (behavior_list);
#line 156 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return result;
#line 1586 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotDatabaseBehavior* data_imports_fspot_db_fspot_database_behavior_construct (GType object_type, UtilsVersionNumber* version, GError** error) {
	DataImportsFSpotDbFSpotDatabaseBehavior * self = NULL;
	UtilsVersionNumber* _tmp0_ = NULL;
	UtilsVersionNumber* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	DataImportsFSpotDbFSpotTableBehavior* photos_generic_behavior = NULL;
	UtilsVersionNumber* _tmp8_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp9_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp10_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* tags_generic_behavior = NULL;
	UtilsVersionNumber* _tmp13_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp14_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp15_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* photo_tags_generic_behavior = NULL;
	UtilsVersionNumber* _tmp18_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp19_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp20_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* photo_versions_generic_behavior = NULL;
	UtilsVersionNumber* _tmp23_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp24_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp25_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* rolls_generic_behavior = NULL;
	UtilsVersionNumber* _tmp28_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp29_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp30_ = NULL;
	gboolean _tmp33_ = FALSE;
	gboolean _tmp34_ = FALSE;
	gboolean _tmp35_ = FALSE;
	gboolean _tmp36_ = FALSE;
	DataImportsFSpotDbFSpotTableBehavior* _tmp37_ = NULL;
	GError * _inner_error_ = NULL;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (UTILS_IS_VERSION_NUMBER (version), NULL);
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self = (DataImportsFSpotDbFSpotDatabaseBehavior*) g_object_new (object_type, NULL);
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = version;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = data_imports_fspot_db_fspot_database_behavior_MIN_UNSUPPORTED_VERSION;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp2_ = gee_comparable_compare_to (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COMPARABLE, GeeComparable), _tmp1_);
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp2_ >= 0) {
#line 1633 "FSpotDatabaseBehavior.c"
		UtilsVersionNumber* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GError* _tmp6_ = NULL;
		GError* _tmp7_ = NULL;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp3_ = version;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp4_ = utils_version_number_to_string (_tmp3_);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp5_ = _tmp4_;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp6_ = g_error_new (SPIT_DATA_IMPORTS_DATA_IMPORT_ERROR, SPIT_DATA_IMPORTS_DATA_IMPORT_ERROR_UNSUPPORTED_VERSION, "Version %s is not yet supported", _tmp5_);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp7_ = _tmp6_;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_g_free0 (_tmp5_);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_inner_error_ = _tmp7_;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		if (_inner_error_->domain == SPIT_DATA_IMPORTS_DATA_IMPORT_ERROR) {
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			g_propagate_error (error, _inner_error_);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (self);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			return NULL;
#line 1661 "FSpotDatabaseBehavior.c"
		} else {
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			g_clear_error (&_inner_error_);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			return NULL;
#line 1669 "FSpotDatabaseBehavior.c"
		}
	}
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp8_ = version;
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp9_ = data_imports_fspot_db_fspot_database_behavior_find_behavior (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTOS_TABLE_TABLE_NAME, _tmp8_);
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	photos_generic_behavior = _tmp9_;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp10_ = photos_generic_behavior;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp10_ != NULL) {
#line 1682 "FSpotDatabaseBehavior.c"
		DataImportsFSpotDbFSpotTableBehavior* _tmp11_ = NULL;
		DataImportsFSpotDbFSpotTableBehavior* _tmp12_ = NULL;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp11_ = photos_generic_behavior;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR) ? ((DataImportsFSpotDbFSpotTableBehavior*) _tmp11_) : NULL);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_g_object_unref0 (self->priv->photos_behavior);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		self->priv->photos_behavior = _tmp12_;
#line 1693 "FSpotDatabaseBehavior.c"
	}
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp13_ = version;
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp14_ = data_imports_fspot_db_fspot_database_behavior_find_behavior (DATA_IMPORTS_FSPOT_DB_FSPOT_TAGS_TABLE_TABLE_NAME, _tmp13_);
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	tags_generic_behavior = _tmp14_;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp15_ = tags_generic_behavior;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp15_ != NULL) {
#line 1705 "FSpotDatabaseBehavior.c"
		DataImportsFSpotDbFSpotTableBehavior* _tmp16_ = NULL;
		DataImportsFSpotDbFSpotTableBehavior* _tmp17_ = NULL;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp16_ = tags_generic_behavior;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR) ? ((DataImportsFSpotDbFSpotTableBehavior*) _tmp16_) : NULL);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_g_object_unref0 (self->priv->tags_behavior);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		self->priv->tags_behavior = _tmp17_;
#line 1716 "FSpotDatabaseBehavior.c"
	}
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp18_ = version;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp19_ = data_imports_fspot_db_fspot_database_behavior_find_behavior (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_TAGS_TABLE_TABLE_NAME, _tmp18_);
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	photo_tags_generic_behavior = _tmp19_;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp20_ = photo_tags_generic_behavior;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp20_ != NULL) {
#line 1728 "FSpotDatabaseBehavior.c"
		DataImportsFSpotDbFSpotTableBehavior* _tmp21_ = NULL;
		DataImportsFSpotDbFSpotTableBehavior* _tmp22_ = NULL;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp21_ = photo_tags_generic_behavior;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR) ? ((DataImportsFSpotDbFSpotTableBehavior*) _tmp21_) : NULL);
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_g_object_unref0 (self->priv->photo_tags_behavior);
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		self->priv->photo_tags_behavior = _tmp22_;
#line 1739 "FSpotDatabaseBehavior.c"
	}
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp23_ = version;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp24_ = data_imports_fspot_db_fspot_database_behavior_find_behavior (DATA_IMPORTS_FSPOT_DB_FSPOT_PHOTO_VERSIONS_TABLE_TABLE_NAME, _tmp23_);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	photo_versions_generic_behavior = _tmp24_;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp25_ = photo_versions_generic_behavior;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp25_ != NULL) {
#line 1751 "FSpotDatabaseBehavior.c"
		DataImportsFSpotDbFSpotTableBehavior* _tmp26_ = NULL;
		DataImportsFSpotDbFSpotTableBehavior* _tmp27_ = NULL;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp26_ = photo_versions_generic_behavior;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR) ? ((DataImportsFSpotDbFSpotTableBehavior*) _tmp26_) : NULL);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_g_object_unref0 (self->priv->photo_versions_behavior);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		self->priv->photo_versions_behavior = _tmp27_;
#line 1762 "FSpotDatabaseBehavior.c"
	}
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp28_ = version;
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp29_ = data_imports_fspot_db_fspot_database_behavior_find_behavior (DATA_IMPORTS_FSPOT_DB_FSPOT_ROLLS_TABLE_TABLE_NAME, _tmp28_);
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	rolls_generic_behavior = _tmp29_;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp30_ = rolls_generic_behavior;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp30_ != NULL) {
#line 1774 "FSpotDatabaseBehavior.c"
		DataImportsFSpotDbFSpotTableBehavior* _tmp31_ = NULL;
		DataImportsFSpotDbFSpotTableBehavior* _tmp32_ = NULL;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp31_ = rolls_generic_behavior;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp32_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR) ? ((DataImportsFSpotDbFSpotTableBehavior*) _tmp31_) : NULL);
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_g_object_unref0 (self->priv->rolls_behavior);
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		self->priv->rolls_behavior = _tmp32_;
#line 1785 "FSpotDatabaseBehavior.c"
	}
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp37_ = self->priv->photos_behavior;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp37_ == NULL) {
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp36_ = TRUE;
#line 1793 "FSpotDatabaseBehavior.c"
	} else {
		DataImportsFSpotDbFSpotTableBehavior* _tmp38_ = NULL;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp38_ = self->priv->tags_behavior;
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp36_ = _tmp38_ == NULL;
#line 1800 "FSpotDatabaseBehavior.c"
	}
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp36_) {
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp35_ = TRUE;
#line 1806 "FSpotDatabaseBehavior.c"
	} else {
		DataImportsFSpotDbFSpotTableBehavior* _tmp39_ = NULL;
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp39_ = self->priv->photo_tags_behavior;
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp35_ = _tmp39_ == NULL;
#line 1813 "FSpotDatabaseBehavior.c"
	}
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp35_) {
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp34_ = TRUE;
#line 1819 "FSpotDatabaseBehavior.c"
	} else {
		DataImportsFSpotDbFSpotTableBehavior* _tmp40_ = NULL;
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp40_ = self->priv->photo_versions_behavior;
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp34_ = _tmp40_ == NULL;
#line 1826 "FSpotDatabaseBehavior.c"
	}
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp34_) {
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp33_ = TRUE;
#line 1832 "FSpotDatabaseBehavior.c"
	} else {
		DataImportsFSpotDbFSpotTableBehavior* _tmp41_ = NULL;
#line 181 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp41_ = self->priv->rolls_behavior;
#line 181 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp33_ = _tmp41_ == NULL;
#line 1839 "FSpotDatabaseBehavior.c"
	}
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	if (_tmp33_) {
#line 1843 "FSpotDatabaseBehavior.c"
		UtilsVersionNumber* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		GError* _tmp45_ = NULL;
		GError* _tmp46_ = NULL;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp42_ = version;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp43_ = utils_version_number_to_string (_tmp42_);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp44_ = _tmp43_;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp45_ = g_error_new (SPIT_DATA_IMPORTS_DATA_IMPORT_ERROR, SPIT_DATA_IMPORTS_DATA_IMPORT_ERROR_UNSUPPORTED_VERSION, "Version %s is not supported", _tmp44_);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_tmp46_ = _tmp45_;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_g_free0 (_tmp44_);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		_inner_error_ = _tmp46_;
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
		if (_inner_error_->domain == SPIT_DATA_IMPORTS_DATA_IMPORT_ERROR) {
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			g_propagate_error (error, _inner_error_);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (rolls_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (photo_versions_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (photo_tags_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (tags_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (photos_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (self);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			return NULL;
#line 1881 "FSpotDatabaseBehavior.c"
		} else {
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (rolls_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (photo_versions_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (photo_tags_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (tags_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			_g_object_unref0 (photos_generic_behavior);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			g_clear_error (&_inner_error_);
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
			return NULL;
#line 1899 "FSpotDatabaseBehavior.c"
		}
	}
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (rolls_generic_behavior);
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (photo_versions_generic_behavior);
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (photo_tags_generic_behavior);
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (tags_generic_behavior);
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (photos_generic_behavior);
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return self;
#line 1914 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotDatabaseBehavior* data_imports_fspot_db_fspot_database_behavior_new (UtilsVersionNumber* version, GError** error) {
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return data_imports_fspot_db_fspot_database_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, version, error);
#line 1921 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_photos_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self) {
	DataImportsFSpotDbFSpotTableBehavior* result = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp0_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp1_ = NULL;
#line 186 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR (self), NULL);
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = self->priv->photos_behavior;
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	result = _tmp1_;
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return result;
#line 1939 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_tags_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self) {
	DataImportsFSpotDbFSpotTableBehavior* result = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp0_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp1_ = NULL;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR (self), NULL);
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = self->priv->tags_behavior;
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	result = _tmp1_;
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return result;
#line 1957 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_photo_tags_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self) {
	DataImportsFSpotDbFSpotTableBehavior* result = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp0_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp1_ = NULL;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR (self), NULL);
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = self->priv->photo_tags_behavior;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	result = _tmp1_;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return result;
#line 1975 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_photo_versions_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self) {
	DataImportsFSpotDbFSpotTableBehavior* result = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp0_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp1_ = NULL;
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR (self), NULL);
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = self->priv->photo_versions_behavior;
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	result = _tmp1_;
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return result;
#line 1993 "FSpotDatabaseBehavior.c"
}


DataImportsFSpotDbFSpotTableBehavior* data_imports_fspot_db_fspot_database_behavior_get_rolls_behavior (DataImportsFSpotDbFSpotDatabaseBehavior* self) {
	DataImportsFSpotDbFSpotTableBehavior* result = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp0_ = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp1_ = NULL;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_BEHAVIOR (self), NULL);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = self->priv->rolls_behavior;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	result = _tmp1_;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	return result;
#line 2011 "FSpotDatabaseBehavior.c"
}


static void data_imports_fspot_db_fspot_database_behavior_class_init (DataImportsFSpotDbFSpotDatabaseBehaviorClass * klass) {
	gint* _tmp0_ = NULL;
	gint* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	UtilsVersionNumber* _tmp2_ = NULL;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	data_imports_fspot_db_fspot_database_behavior_parent_class = g_type_class_peek_parent (klass);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	g_type_class_add_private (klass, sizeof (DataImportsFSpotDbFSpotDatabaseBehaviorPrivate));
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_database_behavior_finalize;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_ = g_new0 (gint, 1);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp0_[0] = 19;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1_ = _tmp0_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp1__length1 = 1;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_tmp2_ = utils_version_number_new (_tmp1_, 1);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	data_imports_fspot_db_fspot_database_behavior_MIN_UNSUPPORTED_VERSION = _tmp2_;
#line 2038 "FSpotDatabaseBehavior.c"
}


static void data_imports_fspot_db_fspot_database_behavior_instance_init (DataImportsFSpotDbFSpotDatabaseBehavior * self) {
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self->priv = DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_BEHAVIOR_GET_PRIVATE (self);
#line 2045 "FSpotDatabaseBehavior.c"
}


static void data_imports_fspot_db_fspot_database_behavior_finalize (GObject* obj) {
	DataImportsFSpotDbFSpotDatabaseBehavior * self;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_BEHAVIOR, DataImportsFSpotDbFSpotDatabaseBehavior);
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->photos_behavior);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->tags_behavior);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->photo_tags_behavior);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->photo_versions_behavior);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	_g_object_unref0 (self->priv->rolls_behavior);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotDatabaseBehavior.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_database_behavior_parent_class)->finalize (obj);
#line 2065 "FSpotDatabaseBehavior.c"
}


/**
 * A class that consolidates the behavior of all F-Spot tables (apart from meta)
 * and is the one place to check whether the database version is supported.
 */
GType data_imports_fspot_db_fspot_database_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_database_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_database_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotDatabaseBehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_database_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotDatabaseBehavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_database_behavior_instance_init, NULL };
		GType data_imports_fspot_db_fspot_database_behavior_type_id;
		data_imports_fspot_db_fspot_database_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotDatabaseBehavior", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_fspot_db_fspot_database_behavior_type_id__volatile, data_imports_fspot_db_fspot_database_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_database_behavior_type_id__volatile;
}



